0.2.40 (2024-11-03)
-------------------
Support for Wagtail 6.3

Improved the performance of the web player by
- #167 Waiting for the load event before initializing the player (instead of using DOMContentLoaded)
- #167 Only initializing the player once the player is visible in the viewport
- #167 Save space for the player in the layout, even if it's not visible
- #167 New podlove player web component
